# cpct

[![PyPI - Version](https://img.shields.io/pypi/v/cpct.svg)](https://pypi.org/project/cpct)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cpct.svg)](https://pypi.org/project/cpct)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)
- [chipy](https://chipy.dev)

## Installation

```console
pip install cpct
OR
pip install cpct --upgrade -t c:/chipy-scripts/
```
# DISCLAIMER:
This product isn't affiliated with or endorsed by Grinding Gear Games in any way.

## License

`cpct` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
